pub fn enter<R>(f: impl FnOnce() -> R) -> RExpand description
Creates new session globals on the current thread if they doesn’t exist already and then executes the given closure.
Prefer Session::enter_parallel to this function if possible to also set the source map and
thread pool.
Using this instead of Session::enter_parallel may cause unexpected panics.